@@ -19,6 +19,7 @@ from typing import Tuple, List, Optional
 
 class Hue(Enum):
     """Container for basic colors."""
+
     RED = 0
     YELLOW = 1
     GREEN = 2
@@ -33,7 +34,7 @@ HUE_LUT = {
     Hue.GREEN: Hue.BLUE,
     Hue.CYAN: Hue.RED,
     Hue.BLUE: Hue.YELLOW,
-    Hue.MAGENTA: Hue.CYAN
+    Hue.MAGENTA: Hue.CYAN,
 }
 
 
@@ -47,11 +48,12 @@ class ColorGenerator:
             initial_color: The color to start with.
         """
         self.initial_color = colorsys.rgb_to_hls(
-            *(initial_color_channel / 255.0 for initial_color_channel in initial_color))
+            *(initial_color_channel / 255.0 for initial_color_channel in initial_color)
+        )
         self.current_color: Optional[List[float]] = None
         self.current_iteration = 0
 
-    def __iter__(self) -> 'ColorGenerator':
+    def __iter__(self) -> "ColorGenerator":
         """Creates an iterator from the color generator class."""
         return self
 
@@ -73,7 +75,7 @@ class ColorGenerator:
             if self.current_iteration == 1:
                 self.current_iteration += 1
 
-            next_hue = HUE_LUT[Hue(self.current_iteration % len(Hue))].value
+            next_hue = float(HUE_LUT[Hue(self.current_iteration % len(Hue))].value)
 
             iteration = int(self.current_iteration / len(Hue))
             next_hue += iteration / (iteration + 1.0)
